==> xl-react-components-0.16.62.tgz: package/app/pages/dip-page/dip-initial-state.js <==
/* eslint-disable sort-keys, max-lines */
const type = 'dip';

export const dipInitialState = {
    dipBoolean1: {
        displayMode: 'edit',
        model: false,
        metadata: {
            label: "I'm a boolean",
            description: 'This is my check field.'
        },
        navigationDescription: 'xl-react-dip-boolean',
        navigationTitle: 'DIP Boolean',
        type
    },
    dipInteger1: {
        displayMode: 'edit',
        metadata: {
            label: "I'm an integer",
            description: 'This is my int field.'
        },
        navigationDescription: 'xl-react-dip-integer',
        navigationTitle: 'XL DIP Integer',
        type
    },
    dipInteger2: {
        displayMode: 'edit',
        metadata: {
            default: 30,
            label: "I'm an integer",
            description: 'This is my int field.'
        },
        navigationDescription: 'xl-react-dip-integer',
        navigationTitle: 'XL DIP Integer Default',
        type
    },
    dipString1: {
        metadata: {
            label: 'String me',
            name: 'application.string',
            description: 'This is my string field.',
            placeholder: 'String placeholder'
        },
        navigationDescription: 'xl-react-dip-string',
        navigationTitle: 'XL Dip String',
        type
    },
    dipString2: {
        metadata: {
            default: 'value',
            label: 'String me',
            name: 'application.string',
            description: 'This is my string field.'
        },
        navigationDescription: 'xl-react-dip-string',
        navigationTitle: 'XL Dip String Default',
        type
    },
    dipCi1: {
        metadata: {
            description: 'This is my autocomplete field.',
            label: 'Autocomplete',
            name: 'application.autocomplete'
        },
        navigationDescription: 'xl-react-dip-ci',
        navigationTitle: 'XL DIP Ci',
        type
    },
    dipCi2: {
        metadata: {
            description: 'With simple string',
            default: 'Application2',
            label: 'Ci',
            name: 'application.autocomplete',
            referencedType: 'referencedType'
        },
        navigationDescription: 'xl-react-dip-ci',
        navigationTitle: 'XL DIP Ci Default',
        type
    },
    dipArrayOfStrings1: {
        metadata: {
            default: [
                'Item 1',
                'Item 2',
                'Item 3',
                'Item 4'
            ],
            name: 'NameList3',
            label: 'Array of strings',
            description: 'Find the description here',
            emptyPlaceholder: 'No items',
            requiredText: 'Custom required text overriding default required text!'
        },
        navigationDescription: 'xl-react-dip-list',
        navigationTitle: 'DIP List',
        type
    },
    dipArrayOfStrings2: {
        metadata: {
            default: [
                'Application1',
                'Application4'
            ],
            name: 'NameList4',
            label: 'Array of strings with suggestions',
            description: 'Can provide you some suggestions',
            emptyPlaceholder: 'No items yet'
        },
        navigationDescription: 'xl-react-dip-list',
        navigationTitle: 'XL DIP List With Autocomplete',
        type
    },
    dipEnum1: {
        metadata: {
            enumValues: [
                'ace',
                'albatross',
                'eagle',
                'birdie',
                'par',
                'bogey'
            ],
            label: 'Enum Label',
            default: 'birdie',
            description: 'Select a string'
        },
        model: 'eagle',
        navigationDescription: 'xl-react-dip-enum',
        navigationTitle: 'DIP Enum',
        type
    },
    dipMapStringString1: {
        metadata: {
            description: 'Find the description here',
            label: 'Dictionary',
            name: 'NameMap'
        },
        model: {
            'Name': 'Marc',
            'Surname': 'Dupont',
            'Age': 39,
            'Street': '433 Boulevard des templiers',
            'Zipcode': 74003,
            'City': 'Paris',
            'Phone': '0123456789',
            'Mobile Phone': '+31123456789'
        },
        navigationDescription: 'xl-react-dip-map-string-string',
        navigationTitle: 'DIP Map String String',
        type,
        extraBindingSections: [
            {
                label: 'Password',
                name: 'metadata.password',
                type: 'boolean',
                value: false
            }
        ]
    },
    dipDateTime1: {
        metadata: {
            label: 'Datetime Label',
            description: 'Pick a date and time'
        },
        navigationDescription: 'xl-react-dip-datetime',
        navigationTitle: 'DIP Date time',
        type
    },
    dipStringSet1: {
        metadata: {
            description: 'Find the description here',
            label: 'My items',
            name: 'NameSet3',
            requiredText: 'Custom required text overriding default required text!'
        },
        model: ['Item 1', 'Item 2', 'Item 3', 'Item 4'],
        navigationDescription: 'dip-set-of-strings',
        navigationTitle: 'DIP Set Of Strings',
        type
    },
    dipListOfCi1: {
        emptyPlaceholder: 'No items selected yet',
        metadata: {
            name: 'NameListOfCi1',
            label: 'List of CIs',
            description: 'Find the description here'
        },
        model: [
            {
                id: 'Item 1',
                type: 10
            },
            {
                id: 'Item 2',
                type: 10
            },
            {
                id: 'Item 3',
                type: 10
            },
            {
                id: 'Item 4',
                type: 10
            },
            {
                id: 'Item 5',
                type: 10
            }
        ],
        navigationDescription: 'dip-list-of-ci',
        navigationTitle: 'DIP List Of CI',
        newItemSuffix: ' (New CI)',
        type
    },
    dipSetOfCi1: {
        emptyPlaceholder: 'No items selected yet',
        metadata: {
            name: 'NameSetOfCi1',
            label: 'Set of CIs',
            description: 'Find the description here'
        },
        model: [
            {
                id: 'Item 1',
                type: 10
            },
            {
                id: 'Item 5',
                type: 10
            },
            {
                id: 'Item 4',
                type: 10
            },
            {
                id: 'Item 2',
                type: 10
            },
            {
                id: 'Item 3',
                type: 10
            }
        ],
        navigationDescription: 'dip-set-of-ci',
        navigationTitle: 'DIP Set Of CI',
        newItemSuffix: ' (New CI)',
        type
    }
};
/* eslint-enable sort-keys, max-lines */

==> xl-react-components-0.18.103.tgz: package/app/pages/dip-page/dip-initial-state.js <==
/* eslint-disable sort-keys, max-lines */
import moment from 'moment';
import R from 'ramda';
import {enumViews} from '../../xl-react-dip/xl-react-dip-enum/dip-enum-service';

const type = 'dip';

export const dipInitialState = {
    dipBoolean1: {
        displayMode: 'edit',
        model: false,
        metadata: {
            kind: 'BOOLEAN',
            label: 'I\'m a boolean',
            description: 'This is my check field.'
        },
        navigationDescription: 'xl-react-dip-boolean',
        navigationTitle: 'DIP Boolean',
        type
    },
    dipInteger1: {
        displayMode: 'edit',
        metadata: {
            kind: 'INTEGER',
            label: 'I\'m an integer',
            description: 'This is my int field.'
        },
        navigationDescription: 'xl-react-dip-integer',
        navigationTitle: 'XL DIP Integer',
        type
    },
    dipInteger2: {
        displayMode: 'edit',
        metadata: {
            default: 30,
            kind: 'INTEGER',
            label: 'I\'m an integer',
            description: 'This is my int field.'
        },
        navigationDescription: 'xl-react-dip-integer',
        navigationTitle: 'XL DIP Integer Default',
        type
    },
    dipString1: {
        metadata: {
            kind: 'STRING',
            label: 'String me',
            name: 'application.string',
            description: 'This is my string field.',
            placeholder: 'String placeholder'
        },
        navigationDescription: 'xl-react-dip-string',
        navigationTitle: 'XL Dip String',
        type
    },
    dipString2: {
        metadata: {
            default: 'value',
            kind: 'STRING',
            label: 'String me',
            name: 'application.string',
            description: 'This is my string field.'
        },
        navigationDescription: 'xl-react-dip-string',
        navigationTitle: 'XL Dip String Default',
        type
    },
    dipCi1: {
        metadata: {
            description: 'This is my autocomplete field.',
            kind: 'CI',
            label: 'Autocomplete',
            name: 'application.autocomplete'
        },
        navigationDescription: 'xl-react-dip-ci',
        navigationTitle: 'XL DIP Ci',
        type
    },
    dipCi2: {
        metadata: {
            description: 'With simple string',
            default: 'Application2',
            kind: 'CI',
            label: 'Ci',
            name: 'application.autocomplete',
            referencedType: 'referencedType'
        },
        navigationDescription: 'xl-react-dip-ci',
        navigationTitle: 'XL DIP Ci Default',
        type
    },
    dipArrayOfStrings1: {
        metadata: {
            default: [
                'Item 1',
                'Item 2',
                'Item 3',
                'Item 4'
            ],
            kind: 'LIST_OF_STRING',
            name: 'NameList3',
            label: 'Array of strings',
            description: 'Find the description here',
            emptyPlaceholder: 'No items',
            requiredText: 'Custom required text overriding default required text!'
        },
        navigationDescription: 'xl-react-dip-list',
        navigationTitle: 'DIP List',
        type
    },
    dipArrayOfStrings2: {
        metadata: {
            default: [
                'Application1',
                'Application4'
            ],
            kind: 'LIST_OF_STRING',
            name: 'NameList4',
            label: 'Array of strings with suggestions',
            description: 'Can provide you some suggestions',
            emptyPlaceholder: 'No items yet'
        },
        navigationDescription: 'xl-react-dip-list',
        navigationTitle: 'XL DIP List With Autocomplete',
        type
    },
    dipEnum1: {
        metadata: {
            enumValues: [
                'ace',
                'albatross',
                'eagle',
                'birdie',
                'par',
                'bogey'
            ],
            kind: 'ENUM',
            label: 'Enum Label',
            default: 'birdie',
            description: 'Select a string',
            name: 'dipEnum'
        },
        model: 'eagle',
        name: 'dipEnum',
        navigationDescription: 'xl-react-dip-enum',
        navigationTitle: 'DIP Enum',
        type,
        extraBindingSections: [{
            clazzName: 'change-view',
            label: 'View',
            model: '',
            name: 'metadata.view',
            type: 'select',
            values: R.values(enumViews)
        }]
    },
    dipMapStringString1: {
        metadata: {
            description: 'Find the description here',
            kind: 'MAP_STRING_STRING',
            label: 'Dictionary',
            name: 'NameMap'
        },
        model: {
            'Name': 'Marc',
            'Surname': 'Dupont',
            'Age': 39,
            'Street': '433 Boulevard des templiers',
            'Zipcode': 74003,
            'City': 'Paris',
            'Phone': '0123456789',
            'Mobile Phone': '+31123456789'
        },
        navigationDescription: 'xl-react-dip-map-string-string',
        navigationTitle: 'DIP Map String String',
        type,
        extraBindingSections: [
            {
                label: 'Password',
                name: 'metadata.password',
                type: 'boolean',
                value: false
            }
        ]
    },
    dipDateTime1: {
        model: moment({
            year: 2016, month: 10, day: 9, hours: 15, minutes: 10, seconds: 0, milliseconds: 0
        }),
        metadata: {
            kind: 'DATE',
            label: 'Datetime Label',
            description: 'Pick a date and time'
        },
        navigationDescription: 'xl-react-dip-datetime',
        navigationTitle: 'DIP Date time',
        type
    },
    dipStringSet1: {
        metadata: {
            description: 'Find the description here',
            kind: 'SET_OF_STRING',
            label: 'My items',
            name: 'NameSet3',
            requiredText: 'Custom required text overriding default required text!'
        },
        model: ['Item 1', 'Item 2', 'Item 3', 'Item 4'],
        navigationDescription: 'dip-set-of-strings',
        navigationTitle: 'DIP Set Of Strings',
        type
    },
    dipListOfCi1: {
        emptyPlaceholder: 'No items selected yet',
        metadata: {
            kind: 'LIST_OF_CI',
            name: 'NameListOfCi1',
            label: 'List of CIs',
            description: 'Find the description here'
        },
        model: [
            {
                id: 'Item 1',
                type: 10
            },
            {
                id: 'Item 2',
                type: 10
            },
            {
                id: 'Item 3',
                type: 10
            },
            {
                id: 'Item 4',
                type: 10
            },
            {
                id: 'Item 5',
                type: 10
            }
        ],
        navigationDescription: 'dip-list-of-ci',
        navigationTitle: 'DIP List Of CI',
        newItemSuffix: ' (New CI)',
        type
    },
    dipSetOfCi1: {
        emptyPlaceholder: 'No items selected yet',
        metadata: {
            kind: 'SET_OF_CI',
            name: 'NameSetOfCi1',
            label: 'Set of CIs',
            description: 'Find the description here'
        },
        model: [
            {
                id: 'Item 1',
                type: 10
            },
            {
                id: 'Item 5',
                type: 10
            },
            {
                id: 'Item 4',
                type: 10
            },
            {
                id: 'Item 2',
                type: 10
            },
            {
                id: 'Item 3',
                type: 10
            }
        ],
        navigationDescription: 'dip-set-of-ci',
        navigationTitle: 'DIP Set Of CI',
        newItemSuffix: ' (New CI)',
        type
    }
};
/* eslint-enable sort-keys, max-lines */
